%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%MATLAB FILES TO CREATE VECTOR PLOTS USED TO FABRICATE PAPER/ DOUBLE-SIDED 
%TAPE MODELS SHOWN IN:
%
%RATIONAL DESIGN OF 3D RECONFIGURABLE PRISMATIC ARCHITECTED MATERIALS
%http://www.nature.com/nature/journal/v541/n7637/full/nature20824.html
%
%WRITTEN BY JOHANNES T.B. OVERVELDE
%
%FOR ANY QUESTION RELATED TO THE MATLAB FILES, PLEASE CONTACT JOHANNES
%OVERVELDE AT J.T.B.OVERVELDE@GMAIL.COM (WWW.OVERVELDE.COM)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear, close all, clc;

%==========================
%==> USER INPUT STARTS HERE
%==========================

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%MAIN DESIGN VARIABLE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Change the linebelow to make different extrusions. 
index=[0 1 0 1];
%A few examples:
%index=[0 0 0] will create an extruded triangle with no tabs
%index=[0 0 1] will create an extruded triangle with one tab
%index=[1 1 1] will create an extruded triangle with three tabs
%index=[0 1 0 1] will create an extruded square with two tabs
%index=[0 0 0 1 0 0 0 0 0 0] will create an extruded decagon with one tab

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%MORE ADVANCED VARIABLES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Only change for advanced use!
L=1.0;    %Unit length edges
H=1.5/35; %Hinge thickness
D=1;      %Width of faces
B=1/7;    %Block used to fix center pieces
F1=1/3;   %Aspect ratio of flap
F2=1/5;   %Second aspect ratio of flap
F2a=F2;
F3=1/16;  %Third aspect ratio of flap
F4=1/10;  %Fourth aspect ratio of flap

%========================
%==> USER INPUT ENDS HERE
%========================

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%CREATE THE SVG FILES (Don't change anything below)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%
%DESIGN END STEP-1
%%%%%%%%%%%%%%%%%%
x1(1,:)=[0 0,F1*[1/sqrt(2)*(D-H),+1/sqrt(2)*(D-H)]];
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+F2a*[0,+(L-H)]];
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[(D-H)*F4,-(D-H)*F3]];
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[0,-x1(end,4)+(L-H)/2]];
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[x1(end,3:4)-x1(end-1,3:4)]];
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[-(D-H)*F4,-(D-H)*F3]];
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+F2a*[0,(L-H)]];
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+F1*[-1/sqrt(2)*(D-H),1/sqrt(2)*(D-H)]];
%CENTER
for i=1:length(index)
    if index(i)==0
        xo=x1(end,3:4);
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+F1*[1/sqrt(2)*(D-H),-1/sqrt(2)*(D-H)]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+F2*[(D-H),0]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x1(end+1,:)=[x1(end,3:4),[xo(1)+(D-H)/2 x1(end,4)]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+x1(end,3:4)-x1(end-1,3:4)];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[-(D-H)*F3,(D-H)*F4]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+F2*[(D-H),0]];
        x1(end+1,:)=[x1(end,3:4),xo+[D-H,0]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[0,-(L-H)]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[H,0]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[0,L-H]];
    else
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[(D-H),0]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[0,-(L-H)]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[H,0]];
        x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[0,L-H]];
    end
end
%END
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[0,H]];
x1(end+1,:)=[x1(end,3:4),[-H L]];
x1(end+1,:)=[x1(end,3:4),x1(end,3:4)+[0,-L]];
x1(end+1,:)=[x1(end,3:4),[0,0]];

%%%%%%%%%%%%%%%%%%
%DESIGN END STEP-2
%%%%%%%%%%%%%%%%%%
x2(1,:)=[-H -H, -H L];
x2(end+1,:)=[x2(end,3:4), x2(end,3:4)+[H 0]];
%CENTER
for i=1:length(index)
    if index(i)==1
        xo=x2(end,3:4);
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+F1*[1/sqrt(2)*(D-H),1/sqrt(2)*(D-H)]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+F2*[(D-H),0]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[-(D-H)*F3,(D-H)*F4]];
        x2(end+1,:)=[x2(end,3:4),[xo(1)+(D-H)/2 x2(end,4)]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+x2(end,3:4)-x2(end-1,3:4)];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+F2*[(D-H),0]];
        x2(end+1,:)=[x2(end,3:4),xo+[D-H,0]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[H,0]];
    else
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[0,-H]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[0,-(L-H)]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[D-H,0]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[0,L-H]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[0,H]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[H,0]];
    end
end
%END
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[0,-H]];
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+F1*[1/sqrt(2)*(D-H),-1/sqrt(2)*(D-H)]];
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+F2a*[0,-(L-H)]];
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[(D-H)*F4,(D-H)*F3]];
x2(end+1,:)=[x2(end,3:4),[x2(end,3) (L-H)/2]];
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+x2(end,3:4)-x2(end-1,3:4)];
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[-(D-H)*F4,(D-H)*F3]];
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+F2a*[0,-(L-H)]];
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+F1*[-1/sqrt(2)*(D-H),-1/sqrt(2)*(D-H)]];
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[0,-H]];
%END BACK
for i=length(index):-1:1
    if index(i)==0
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[-D,0]];
    else
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[-H,0]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[0,L]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[-(D-H),0]];
        x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[0,-L]];
    end
end
%BEGIN
x2(end+1,:)=[x2(end,3:4),x2(end,3:4)+[-H,0]];

%%%%%%%%%%%%%%%%%%
%DESIGN END STEP-3
%%%%%%%%%%%%%%%%%%
x3=[];
for i=1:length(index)
    if index(i)==1
        x3(end+1,:)=[(i-1)*D,0,(i-1)*D+D-H,0];
    end
end

%%%%%%%%%%%%%%%%%%
%DESIGN END STEP-4
%%%%%%%%%%%%%%%%%%
%BEGINNING
x4(1,:)=[0,0,[0,L-H]];
%CENTER
for i=1:length(index)
    if index(i)==1
        xo=x4(end,3:4);
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[0,H]];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+F1*[1/sqrt(2)*(D-H),1/sqrt(2)*(D-H)]];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+F2*[(D-H),0]];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[-(D-H)*F3,(D-H)*F4]];
        x4(end+1,:)=[x4(end,3:4),[xo(1)+(D-H)/2 x4(end,4)]];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+x4(end,3:4)-x4(end-1,3:4)];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+F2*[(D-H),0]];
        x4(end+1,:)=[x4(end,3:4),xo+[D-H,H]];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[0,-H]];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[H,0]];
    else
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[(D-H),0]];
        x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[H,0]];
    end
end
%END
xo=x4(end,3:4);
x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+F1*[1/sqrt(2)*(D-H),-1/sqrt(2)*(D-H)]];
x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+F2a*[0,-(L-H)]];
x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[(D-H)*F4,(D-H)*F3]];
x4(end+1,:)=[x4(end,3:4),[x4(end,3),xo(2)-(L-H)/2]];
x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+x4(end,3:4)-x4(end-1,3:4)];
x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+[-(D-H)*F4,(D-H)*F3]];
x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+F2a*[0,-(L-H)]];
x4(end+1,:)=[x4(end,3:4),x4(end,3:4)+F1*[-1/sqrt(2)*(D-H),-1/sqrt(2)*(D-H)]];
x4(end+1,:)=[x4(end,3:4),x4(end,3:4)-x4(end,3:4)];

%%%%%%%%%%%%%%%%%%%%%%
%DESIGN CONNECT STEP-1
%%%%%%%%%%%%%%%%%%%%%%
%x1=[0,0];
x5(1,:)=[0,-L+H,[0,-L+H]+F1*[1/sqrt(2)*(D-H),+1/sqrt(2)*(D-H)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F2*[0,+(L-H)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[(D-H)*F4,-(D-H)*F3]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,-x5(end,4)-2*(L-H)/5]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[x5(end,3:4)-x5(end-1,3:4)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[-(D-H)*F4,-(D-H)*F3]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F2*[0,(L-H)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,-x5(end,4)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[x5(end,3:4)-x5(end-1,3:4)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F2*[0,+(L-H)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[(D-H)*F4,-(D-H)*F3]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,-x5(end,4)+2*(L-H)/5]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[x5(end,3:4)-x5(end-1,3:4)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[-(D-H)*F4,-(D-H)*F3]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F2*[0,(L-H)]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F1*[-1/sqrt(2)*(D-H),1/sqrt(2)*(D-H)]];
x5(end+1,:)=[x5(end,3:4)+[0,H],x5(end,3:4)+[-H,H]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,-2*L]];
x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[H,0]];
%CENTER
for i=1:length(index)
    if index(i)==0
        xo=x5(end,3:4);
        %TOP
        x5(end+1,:)=[xo+[0,2*L-H],xo+[0,2*L-H]+F1*[1/sqrt(2)*(D-H),-1/sqrt(2)*(D-H)]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F2*[(D-H),0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x5(end+1,:)=[x5(end,3:4),[xo(1)+(D-H)/2 x5(end,4)]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+x5(end,3:4)-x5(end-1,3:4)];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[-(D-H)*F3,(D-H)*F4]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F2*[(D-H),0]];
        x5(end+1,:)=[x5(end,3:4),xo+[D-H,2*L-H]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,-L+H+B/2]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[H,0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,+L-H-B/2]];
        x5(end+1,:)=[xo+[0,2*L],xo+[0,2*L]+[D,0]];
        %BOTTOM
        x5(end+1,:)=[xo,xo+[(D-H)/2.0-B/2.0,0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,H]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[-(D-H)/2.0+B/2.0,0]];
        x5(end+1,:)=[xo+[D,H],xo+[D,H]+[0,L-H-B/2.0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[H,0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[0,L-H-B/2]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[(D-H)/2.0-B/2,0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[0,H]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[-(D-H)/2.0-H+B/2.0,0]];
    else
        xo=x5(end,3:4);
        %TOP
        x5(end+1,:)=[xo+[0 2*L-H],xo+[0,2*L-H]+[(D-H)/2.0-B/2.0,0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,H]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[-(D-H)/2.0+B/2.0,0]];
        
        x5(end+1,:)=[xo+[D,2*L-H],xo+[D,2*L-H]-[0,L-H-B/2.0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[H,0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,L-H-B/2]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[(D-H)/2.0-B/2,0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,H]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[-(D-H)/2.0-H+B/2.0,0]];
        %BOTTOM
        x5(end+1,:)=[xo+[0,H],xo+[0,H]+F1*[1/sqrt(2)*(D-H),+1/sqrt(2)*(D-H)]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F2*[(D-H),0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[-(D-H)*F3,+(D-H)*F4]];
        x5(end+1,:)=[x5(end,3:4),[xo(1)+(D-H)/2 x5(end,4)]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+x5(end,3:4)-x5(end-1,3:4)];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+F2*[(D-H),0]];
        x5(end+1,:)=[x5(end,3:4),xo+[D-H,H]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[0,+L-H-B/2]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)+[H,0]];
        x5(end+1,:)=[x5(end,3:4),x5(end,3:4)-[0,+L-H-B/2]];
        x5(end+1,:)=[xo,xo+[D,0]];
    end
end
%END
xo=x5(end,3:4);
x5(end+1,:)=[xo,xo+[0,H]];
x5(end+1,:)=[xo+[0,2*L],xo+[0,2*L]+[0,-H]];

%%%%%%%%%%%%%%%%%%%%%%
%DESIGN CONNECT STEP-2
%%%%%%%%%%%%%%%%%%%%%%
x6(1,:)=[0, L -H L];
x6(end+1,:)=[-H L, -H -L];
x6(end+1,:)=[x6(end,3:4), x6(end,3:4)+[H 0]];
%CENTER
for i=1:length(index)
    if index(i)==1
        %TOP
        xo=x6(end,3:4);
        x6(end+1,:)=[x6(end,3:4)+[0,2*L],x6(end,3:4)+[0,2*L]+F1*[1/sqrt(2)*(D-H),1/sqrt(2)*(D-H)]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F2*[(D-H),0]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[-(D-H)*F3,(D-H)*F4]];
        x6(end+1,:)=[x6(end,3:4),[xo(1)+(D-H)/2 x6(end,4)]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+x6(end,3:4)-x6(end-1,3:4)];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F2*[(D-H),0]];
        x6(end+1,:)=[x6(end,3:4),xo+[0,2*L]+[D-H,0]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[H,0]];
        %BOTTOM
        x6(end+1,:)=[xo,xo+[0,(2*L-H)]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[D-H,0]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)-[0,2*L-H]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[H,0]];
    else
        xo=x6(end,3:4);        
        %TOP           
        x6(end+1,:)=[xo+[0,2*L],xo+[0,2*L]+[0,-H]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[0,-(2*L-2*H)]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[D-H,0]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[0,2*L-2*H]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[0,H]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[H,0]];
     
        %BOTTOM
        x6(end+1,:)=[xo,xo+F1*[1/sqrt(2)*(D-H),-1/sqrt(2)*(D-H)]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F2*[(D-H),0]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x6(end+1,:)=[x6(end,3:4),[xo(1)+(D-H)/2 x6(end,4)]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+x6(end,3:4)-x6(end-1,3:4)];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[-(D-H)*F3,(D-H)*F4]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F2*[(D-H),0]];
        x6(end+1,:)=[x6(end,3:4),xo+[D-H,0]];
        x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[H,0]]; 
    end
end
%END
xo=x6(end,3:4);
x6(end+1,:)=[xo,xo+[0 H]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F1*[1/sqrt(2)*(D-H),+1/sqrt(2)*(D-H)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F2*[0,+(L-H)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[(D-H)*F4,-(D-H)*F3]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[0,-x6(end,4)-2*(L-H)/5]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[x6(end,3:4)-x6(end-1,3:4)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[-(D-H)*F4,-(D-H)*F3]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F2*[0,(L-H)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[0,-x6(end,4)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[x6(end,3:4)-x6(end-1,3:4)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F2*[0,+(L-H)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[(D-H)*F4,-(D-H)*F3]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[0,-x6(end,4)+2*(L-H)/5]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[x6(end,3:4)-x6(end-1,3:4)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[-(D-H)*F4,-(D-H)*F3]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F2*[0,(L-H)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+F1*[-1/sqrt(2)*(D-H),1/sqrt(2)*(D-H)]];
x6(end+1,:)=[x6(end,3:4),x6(end,3:4)+[0,(H)]];

%%%%%%%%%%%%%%%%%%%%%%
%DESIGN CONNECT STEP-3
%%%%%%%%%%%%%%%%%%%%%%
x7=[];
for i=1:length(index)
    x7(end+1,:)=[i*D-H,-B/2,i*D,-B/2];
    x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[0 B]];
    x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[-H 0]];
    x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[0 -B]];
end
for i=1:length(index)
    if index(i)==1
        x7(end+1,:)=[(i-1)*D+(D-H)/2-B/2,L-H,(i-1)*D+(D-H)/2+B/2,L-H];
        x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[0 H]];
        x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[-B 0]];
        x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[0 -H]];
    else
        x7(end+1,:)=[(i-1)*D+(D-H)/2-B/2,-L+H,(i-1)*D+(D-H)/2+B/2,-L+H];
        x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[0 -H]];
        x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[-B 0]];
        x7(end+1,:)=[x7(end,3:4),x7(end,3:4)+[0 H]];
    end
end

%%%%%%%%%%%%%%%%%%%%%%
%DESIGN CONNECT STEP-4 
%%%%%%%%%%%%%%%%%%%%%%
x8(1,:)=[0, L-H 0 -L+H];
%CENTER
for i=1:length(index)
    if index(i)==1
        %TOP
        xo=x8(end,3:4);
        x8(end+1,:)=[x8(end,3:4)+[0,2*L-2*H],x8(end,3:4)+[0,2*L-H]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F1*[1/sqrt(2)*(D-H),1/sqrt(2)*(D-H)]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F2*[(D-H),0]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[-(D-H)*F3,(D-H)*F4]];
        x8(end+1,:)=[x8(end,3:4),[xo(1)+(D-H)/2 x8(end,4)]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+x8(end,3:4)-x8(end-1,3:4)];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F2*[(D-H),0]];
        x8(end+1,:)=[x8(end,3:4),xo+[0,2*L-H]+[D-H,0]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[0,-H]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[H,0]];
        %BOTTOM
        x8(end+1,:)=[xo,xo+[D,0]];

    else
        xo=x8(end,3:4);        
        %TOP           
        x8(end+1,:)=[xo+[0,2*L-2*H],xo+[0,2*L-2*H]+[D,0]];
        %BOTTOM
        x8(end+1,:)=[xo,xo-[0,H]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F1*[1/sqrt(2)*(D-H),-1/sqrt(2)*(D-H)]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F2*[(D-H),0]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[-(D-H)*F3,-(D-H)*F4]];
        x8(end+1,:)=[x8(end,3:4),[xo(1)+(D-H)/2 x8(end,4)]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+x8(end,3:4)-x8(end-1,3:4)];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[-(D-H)*F3,(D-H)*F4]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F2*[(D-H),0]];
        x8(end+1,:)=[x8(end,3:4),xo+[D-H,-H]];
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[0,H]]; 
        x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[H,0]];
    end
end
%END
xo=x8(end,3:4);
x8(end+1,:)=[xo,xo+F1*[1/sqrt(2)*(D-H),+1/sqrt(2)*(D-H)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F2*[0,+(L-H)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[(D-H)*F4,-(D-H)*F3]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[0,-x8(end,4)-2*(L-H)/5]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[x8(end,3:4)-x8(end-1,3:4)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[-(D-H)*F4,-(D-H)*F3]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F2*[0,(L-H)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[0,-x8(end,4)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[x8(end,3:4)-x8(end-1,3:4)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F2*[0,+(L-H)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[(D-H)*F4,-(D-H)*F3]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[0,-x8(end,4)+2*(L-H)/5]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[x8(end,3:4)-x8(end-1,3:4)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+[-(D-H)*F4,-(D-H)*F3]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F2*[0,(L-H)]];
x8(end+1,:)=[x8(end,3:4),x8(end,3:4)+F1*[-1/sqrt(2)*(D-H),1/sqrt(2)*(D-H)]];

%%%%%%%%%%%%%%
%PLOT AND SAVE
%%%%%%%%%%%%%%
f1=figure('Position', [0 0 800 800]);hold on;
h1=line([x1(:,1)'; x1(:,3)'],[x1(:,2)'; x1(:,4)'],'color','k');
h2=line([x2(:,1)'; x2(:,3)'],[x2(:,2)'; x2(:,4)'],'color','k');
if length(x3)>0
    h3=line([x3(:,1)'; x3(:,3)'],[x3(:,2)'; x3(:,4)'],'color','k');
end
h4=line([x4(:,1)'; x4(:,3)'],[x4(:,2)'; x4(:,4)'],'color','k');
h5=line([x5(:,1)'; x5(:,3)'],[x5(:,2)'; x5(:,4)'],'color','k');
h6=line([x6(:,1)'; x6(:,3)'],[x6(:,2)'; x6(:,4)'],'color','k');
h7=line([x7(:,1)'; x7(:,3)'],[x7(:,2)'; x7(:,4)'],'color','k');
h8=line([x8(:,1)'; x8(:,3)'],[x8(:,2)'; x8(:,4)'],'color','k');
href=line([0 D],[0 0],'color','r');

axis equal
axis off

saveid{1}={'on','off','off','off','off','off','off','off'};
saveid{2}={'off','on','off','off','off','off','off','off'};
saveid{3}={'off','off','on','off','off','off','off','off'};
saveid{4}={'off','off','off','on','off','off','off','off'};
saveid{5}={'off','off','off','off','on','off','off','off'};
saveid{6}={'off','off','off','off','off','on','off','off'};
saveid{7}={'off','off','off','off','off','off','on','off'};
saveid{8}={'off','off','off','off','off','off','off','on'};
ax = gca;
YLim=ax.YLim;
XLim=ax.XLim;

for savei=1:8
    set(h1,'visible',saveid{savei}{1})
    set(h2,'visible',saveid{savei}{2})
    if length(x3)>0
    set(h3,'visible',saveid{savei}{3})
    end
    set(h4,'visible',saveid{savei}{4})
    set(h5,'visible',saveid{savei}{5})
    set(h6,'visible',saveid{savei}{6})
    set(h7,'visible',saveid{savei}{7})
    set(h8,'visible',saveid{savei}{8})
    if savei<5
        name=['end-[',num2str(index),'] step-',num2str(savei)];
    else
        name=['connect-[',num2str(index),'] step-',num2str(savei-4)];
    end
    axis([XLim YLim])
    saveas(f1,[name,'.svg']) %save file
end

